MODULE module_dry_dep_zhang

    CONTAINS

      real function amin1 (x,y)
        amin1=x
        if (y.lt.x) amin1=y
      return
      end function amin1
      real function amax1 (x,y)
        amax1=x
        if (y.gt.x) amax1=y
      return
      end function amax1

      SUBROUTINE DRYVD  (  z2,     u2,     sd,            &
                           t2,     ts,    srad,    rh,    &
                           fcld,   prec,  COSZEN,   pmb,  &
                           iday, fland, USTAR_INPT,       &
                           Ra, Rb, Rst, Rac, Rg, Rcut, Rns, Rc, Dratio, RM2, VDG, VDP) 
!
!    PURPOSE ---- Calculate dry deposition velocities for 31 gas species 
!                 and 7 aerosol species
!
!    References: 
!      for gas: Zhang et al., 2003.  Atmos. Chem. Phys. 3, 2067-2082 
!      for aerosol: Zhang et al.,2001.  Atmos. Environ. 35, 4463-4470
!
!                        leiming.zhang@ec.gc.ca    1 (416) 739-5734
!
!-----------------------------------------------------------------------
!
!     LUC No.     Vegetation type
!     =====       ===============
!       1         water
!       2         ice
!       3         inland lake
!       4         evergreen needleleaf trees
!       5         evergreen broadleaf trees
!       6         deciduous needleleaf trees
!       7         deciduous broadleaf trees
!       8         tropical broadleaf trees
!       9         drought deciduous trees
!       10        evergreen broadleaf shrub
!       11        deciduous shrubs
!       12        thorn shrubs
!       13        short grass and forbs
!       14        long grass
!       15        crops
!       16        rice
!       17        sugar
!       18        maize
!       19        cotton
!       20        irrigated crops
!       21        urban
!       22        tundra
!       23        swamp
!       24        desert
!       25        mixed wood forests
!       26        transitional forest 
!-----------------------------------------------------------------------
!        KEY   VARIABLES
!-----------------------------------------------------------------------
!  alpha    | Scaling factor based on SO2 (no unit) 
!  beta     | Scaling factor based on O3  (no unit) 
!  brs      | Constant for stomatal resistance(W/m2)
!  bvpd     | Constant for water vapor pressure deficit  (kPa^-1)                   
!  coszen   | Cosine of solar zenith angle         
!  fcld     | Cloud fraction (0.0-1.0)              
!  fland    | fraction of Land types (%)            
!  fsun     | fraction of sunlit leaves (0.0-LAI)  
!  iday     | Julian day                            
!  lai      | Leaf area index  (no unit)           
!  luc      | No. of land use category (26)        
!  mw       | molecular weight for gaseous species  
!           |   (g/mol)                             
!  ng       | No. of gaseous species dry deposited  
!  pardir   | visible beam radiation (W/m2)         
!  pardif   | diffuse visible radiation (W/m2)     
!  pmb      | Surface pressure (mb)              
!  prec     | hourly precipitation amount (mm/hour) 
!  psi1     | Constant for leaf water potential(Mpa)
!  psi2     | Constant for leaf water potential(Mpa)
!  fsnow    | Snow fraction  (0.0-1.0)              
!  ra       | Aerodynamic resistance (s/m)         
!  rac      | IN-canopy aerodynamic resistance (s/m)         
!  rb       | quasi-laminar resistance (s/m)      
!  rc       | total surface resistance (s/m)     
!  rcut     | cuticle resistance (s/m )              
!  rcutdo   | Dry cuticle resistance for O3 (s/m)  
!  rcutds   | Dry cuticle resistance for SO2 (s/m)
!  rcutwo   | Wet cuticle resistance for O3 (s/m)  
!  rg       | Ground  resistance (s/m )                
!  rgo      | Ground  resistance for O3 (s/m)  
!  rgs      | Ground  resistance for SO2 (s/m) 
!  rh       | relative humidity (0.0-1.0)                
!  rm       | mesophyll resistance (s/m)           
!  rsmin    | minimum stomatal resistance (s/m)    
!  rst      | Stomatal resistance (s/m)           
!  sd       | Snow depth        (cm)             
!  sdmax    | Maximum snow depth over which snow  
!           |   fraction for leaves is 1 (cm )              
!  srad     | Solar irradiance (w/m2)          
!  t2       | Temperature  at first level (K)      
!  ts       | Surface temperature (K)             
!  tmin     | Minimum temperature for stomatal     
!           |    opening (C)                      
!  tmax     | Maxmum temperature for stomatal     
!           |    opening (C)                     
!  topt     | Optimum temperature for stomatal   
!           |    opening (C)                     
!  u2       | wind speed at reference height z2(m/s)
!  ustar    | friction velocity (m/s)               
!  VDF      | dry deposition velocity for one LUC   
!  VDG      | gaseous dry deposition velocity (m/s) 
!  wst      | fraction of stomatal closure under   
!           |      wet conditions (0.0-0.5)          
!  z0       | roughness length (m)                
!-----------------------------------------------------------------------
!        KEY   VARIABLES for particle Vd calculation only
!-----------------------------------------------------------------------
!  AEST     | parameter for calculating EIM 
!  BINSIZE  ! radius of a size bin
!  DG       ! geometric mass mean diameter of an aerosol species
!  EB       | Brownian collection efficiency 
!  EIM      | impaction collection efficiency 
!  EIN      | interception collection efficiency 
!  FSIZE     ! fraction (0.-1.) of a size bin
!  GAMA     | parameter for calculating EB 
!  GSD      ! geometric standard deviation of an aerosol species
!  PLLP     | leaf dimenision for calculating EIN 
!  RHOP     ! density of an aerosol species
!  VDPF     | particle dry deposition velocity for one LUC   
!  VDG      | particle dry deposition velocity (m/s) 
!
!-----------------------------------------------------------------------


      IMPLICIT REAL(A-H,O-Z),INTEGER(I-N)        
      PARAMETER (ng=31)        ! NUMBER OF GAS SPECIES DRY DEPOSITED
      PARAMETER (luc=26)       ! NUMBER OF LAND-USE CATEGORIES
      PARAMETER (NSIZE=13)     !number of size bins 
      PARAMETER (np=14)        ! NUMBER OF particle species 

!  paramaters 

      REAL Z01(LUC),    Z02(LUC),  FLAND(LUC)
      REAL LAI(LUC,15),LAI_F

!  paramaters for gaseous Vd submoudle 
      REAL VDG(NG), ALPHA(NG),BETA(NG),MW(NG), RM(NG), RM2(NG)
      REAL, DIMENSION(NG) :: Rb, Rg, Rcut, Rc, Rns, Dratio 
      REAL Rac1(LUC),   Rac2(LUC), RcutdO(LUC), RcutwO(LUC),  &
         RcutdS(LUC),   RgS(LUC),  RgO(LUC),  SDmax(LUC),     &
          Tmin(LUC),   Tmax(LUC),   TOPT(LUC),   BVPD(LUC),   &
         PSI1(LUC),   PSI2(LUC),  RSmin(LUC),    BRS(LUC)
      LOGICAL is_dew, is_rain

!  paramaters for particle Vdsubmoudle 

      REAL VDP(NP), BINSIZE(NSIZE),DB(NSIZE+1),FSIZE(NSIZE)
      REAL DG(NP), GSD(NP), RHOP(NP), SIZE2(NP) 
      REAL AEST(LUC),  PLLP1(LUC), PLLP2(LUC), GAMA(LUC)


!  external functions 
!      external amin1, amax1 


!   Surface Roughness Length [m].
!   Z01 and Z02 are minimum and maximum z0 for each LUC. 

      DATA   Z01             /            &
        0.0 ,  0.01,  0.0 ,  0.9 ,  2.0 , &
        0.4 ,  0.4 ,  2.5 ,  0.6 ,  0.2 , &
        0.05,  0.2 ,  0.04,  0.02,  0.02, &
        0.02,  0.02,  0.02,  0.02,  0.05, &
        1.0 ,  0.03,  0.1 ,  0.04,  0.6 , &
        0.6    /
      DATA   Z02             /            &   
        0.0 ,  0.01,  0.0 ,  0.9 ,  2.0 , &
        0.9 ,  1.0 ,  2.5 ,  0.6 ,  0.2 , &
        0.2 ,  0.2 ,  0.04,  0.1 ,  0.1 , &
        0.1 ,  0.1 ,  0.1 ,  0.2 ,  0.05, &
        1.0 ,  0.03,  0.1 ,  0.04,  0.9 , &
        0.9    /

!   In-canopy aerodynamic resistance  [s/m].
!   Rac1 and Rac2 are minimum and maximum Rac0 for each LUC. 

      DATA   Rac1            /            &
        0   ,  0   ,  0   ,  100 ,  250 , &
        60  ,  100 ,  300 ,  100 ,  60  , &
        20  ,  40  ,  20  ,  10  ,  10  , &
        10  ,  10  ,  10  ,  10  ,  20  , &
        40  ,  0   ,  20  ,  0   ,  100 , &
        100    /
      DATA   Rac2            /            &
        0   ,  0   ,  0   ,  100 ,  250 , &
        100 ,  250 ,  300 ,  100 ,  60  , &
        60  ,  40  ,  20  ,  40  ,  40  , &
        40  ,  40  ,  50  ,  40  ,  20  , &
        40  ,  0   ,  20  ,  0   ,  100 , &
        100    /

!   Dry and wet cuticle resistance for O3  [s/m].

      DATA   RcutdO          /            &
       -999 , -999 , -999 , 4000 , 6000 , &
       4000 , 6000 , 6000 , 8000 , 6000 , &
       5000 , 5000 , 4000 , 4000 , 4000 , &
       4000 , 4000 , 5000 , 5000 , 4000 , &
       6000 , 8000 , 5000 , -999 , 4000 , &
       4000    /
      DATA   RcutwO          /            &
       -999 , -999 , -999 ,  200 ,  400 , &
        200 ,  400 ,  400 ,  400 ,  400 , &
        300 ,  300 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  300 ,  300 ,  200 , &
        400 ,  400 ,  300 , -999 ,  200 , &
        200    /

!   Ground resistance for O3  [s/m].

      DATA   RgO            /             &
       2000 , 2000 , 2000 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  500 , &
        500 ,  500 ,  500 ,  500 ,  200 , &
        200    /

!   Dry cuticle resistance for SO2  [s/m].

      DATA   RcutdS          /            &
       -999 , -999 , -999 , 2000 , 2500 , &
       2000 , 2500 , 2500 , 6000 , 2000 , &
       2000 , 2000 , 1000 , 1000 , 1500 , &
       1500 , 2000 , 2000 , 2000 , 2000 , &
       4000 , 2000 , 1500 , -999 , 2500 , &
       2500    /
!
!    & -999 , -999 , -999 , 1500 , 2500 , 
!    & 1000 , 2000 , 2000 , 6000 , 2000 ,
!    & 2000 , 2000 , 1000 , 1000 , 1500 ,
!    & 1000 , 2000 , 2000 , 2000 , 2000 ,
!    & 4000 , 2000 , 1000 , -999 , 2000 ,
!    & 2000    /

!   Ground resistance for SO2  [s/m].

      DATA   RgS            /             &
         20 ,   70 ,  20  ,  200 ,  100 , &
        200 ,  200 ,  100 ,  300 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
         50 ,  200 ,  200 ,  200 ,   50 , &
        300 ,  300 ,   50 ,  700 ,  200 , &
        200    /

!   Stomatal resistance related parameters. 
!   In sequence: rsmin, brs, tmin, tmax, topt, bvpd, psi1, psi2

      DATA   rsmin            /           &
       -999 , -999 , -999 ,  250 ,  150 , &
        250 ,  150 ,  150 ,  250 ,  150 , &
        150 ,  250 ,  150 ,  100 ,  120 , &
        120 ,  120 ,  250 ,  125 ,  150 , &
        200 ,  150 ,  150 , -999 ,  150 , &
        150   /
      DATA   brs              /           &
       -999 , -999 , -999 ,   44 ,   40 , &
         44 ,   43 ,   40 ,   44 ,   40 , &
         44 ,   44 ,   50 ,   20 ,   40 , &
         40 ,   50 ,   65 ,   65 ,   40 , &
         42 ,   25 ,   40 , -999 ,   44 , &
         43   /
      DATA   tmin             /           &
       -999 , -999 , -999 ,   -5 ,    0 , &
         -5 ,    0 ,    0 ,    0 ,    0 , &
         -5 ,    0 ,    5 ,    5 ,    5 , &
          5 ,    5 ,    5 ,   10 ,    5 , &
          0 ,   -5 ,    0 , -999 ,   -3 , &
          0   /
      DATA   tmax             /           &
       -999 , -999 , -999 ,   40 ,   45 , &
         40 ,   45 ,   45 ,   45 ,   45 , &
         40 ,   45 ,   40 ,   45 ,   45 , &
         45 ,   45 ,   45 ,   45 ,   45 , &
         45 ,   40 ,   45 , -999 ,   42 , &
         45   /
      DATA   topt             /           &
       -999 , -999 , -999 ,   15 ,   30 , &
         15 ,   27 ,   30 ,   25 ,   30 , &
         15 ,   25 ,   30 ,   25 ,   27 , &
         27 ,   25 ,   25 ,   30 ,   25 , &
         22 ,   20 ,   20 , -999 ,   21 , &
         25   /
      DATA   bvpd             /           &
       -999 , -999 , -999 ,  0.31,  0.27, &
        0.31,  0.36,  0.27,  0.31,  0.27, & 
        0.27,  0.27,  0.0 ,  0.0 ,  0.0 , & 
        0.0 ,  0.0 ,  0.0 ,  0.0 ,  0.0 , & 
        0.31,  0.24,  0.27, -999 ,  0.34, &
        0.31   /
      DATA   psi1            /            &
       -999 , -999 , -999 , -2.0 , -1.0 , &
       -2.0 , -1.9 , -1.0 , -1.0 , -2.0 , &
       -2.0 , -2.0 , -1.5 , -1.5 , -1.5 , &
       -1.5 , -1.5 , -1.5 , -1.5 , -1.5 , &
       -1.5 ,    0 , -1.5 , -999 , -2.0 , &
       -2.0    /
      DATA   psi2            /            &
       -999 , -999 , -999 , -2.5 , -5.0 , &
       -2.5 , -2.5 , -5.0 , -4.0 , -4.0 , &
       -4.0 , -3.5 , -2.5 , -2.5 , -2.5 , &
       -2.5 , -2.5 , -2.5 , -2.5 , -2.5 , &
       -3.0 , -1.5 , -2.5 , -999 , -2.5 , &
       -3.0    /

! Leaf area index at the beginning of each month (im=1,13), 
!  minimum LAI (im=14) and maximum LAI (im=15).
! Values of LAI are from GEM, provided by Stephane Belair and Judy St-James,
! with modifications for urban.

      DATA (LAI(6,im), im = 1, 15)/       &
       0.1  , 0.1  , 0.5  , 1.0  , 2.0  , &
       4.0  , 5.0  , 5.0  , 4.0  , 2.0  , &
       1.0  , 0.1  , 0.1  , 0.1  , 5.0  /
      DATA (LAI(7,im), im = 1, 15)/       &
       0.1  , 0.1  , 0.5  , 1.0  , 2.0  , &
       4.0  , 5.0  , 5.0  , 4.0  , 2.0  , &
       1.0  , 0.1  , 0.1  , 0.1  , 5.0  / 
      DATA (LAI(11,im), im = 1, 15)/      &
       0.5  , 0.5  , 1.0  , 1.0  , 1.5  , &
       2.0  , 3.0  , 3.0  , 2.0  , 1.5  , &
       1.0  , 0.5  , 0.5  , 0.5  , 3.0  /
      DATA (LAI(14,im), im = 1, 15)/      &
       0.5  , 0.5  , 0.5  , 0.5  , 0.5  , &
       0.5  , 1.0  , 2.0  , 2.0  , 1.5  , &
       1.0  , 1.0  , 0.5  , 0.5  , 2.0  /
      DATA (LAI(15,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.0  , 3.0  , 3.5  , 4.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 4.0  /
      DATA (LAI(16,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.5  , 4.0  , 5.0  , 6.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 6.0  /
      DATA (LAI(17,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       3.0  , 4.0  , 4.5  , 5.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 5.0  /
      DATA (LAI(18,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.0  , 3.0  , 3.5  , 4.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 4.0  /
      DATA (LAI(19,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       3.0  , 4.0  , 4.5  , 5.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 5.0  /  
      DATA (LAI(21,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.1  , 0.5  , &
       1.0  , 1.0  , 1.0  , 1.0  , 1.0  , &
       0.4  , 0.1  , 0.1  , 0.1  , 1.0  /
      DATA (LAI(22,im), im = 1, 15)/      &
       1.0  , 1.0  , 0.5  , 0.1  , 0.1  , &
       0.1  , 0.1  , 1.0  , 2.0  , 1.5  , &
       1.5  , 1.0  , 1.0  , 0.1  , 2.0  /
      DATA (LAI(25,im), im = 1, 15)/      &
       3.0  , 3.0  , 3.0  , 4.0  , 4.5  , &
       5.0  , 5.0  , 5.0  , 4.0  , 3.0  , &
       3.0  , 3.0  , 3.0  , 3.0  , 5.0  /
      DATA (LAI(26,im), im = 1, 15)/      &
       3.0  , 3.0  , 3.0  , 4.0  , 4.5  , &
       5.0  , 5.0  , 5.0  , 4.0  , 3.0  , &
       3.0  , 3.0  , 3.0  , 3.0  , 5.0  /
 
!  Gas Properties (Total 31 species)
  
!  Mesophyll resistance RM, scaling factors ALPHA and BETA, molecular weight.

      DATA   RM            /              &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  100., &
       100. , 100. , 100. ,  100.,  0.  , &
       100. , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  100., &
       100.     / 

      DATA   ALPHA          /             &
       1.   , 1.   , 0.   ,  0.  ,  1.  , &
       10.  , 2.   , 5.   ,  1.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.8 ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.01 , 0.6  ,  0.6 ,  0.4 , &
       0.01 , 2.   , 1.5  ,  0.1 ,  0.  , &
       0.       / 

      DATA   BETA          /              &
       0.   , 1.   , 0.8  ,  1.  ,  1.  , &
       10.  , 2.   , 5.   ,  0.0 ,  0.6 , &
       0.6  , 0.8  , 0.3  ,  0.2 ,  0.05, &
       0.05 , 0.05 , 0.05 ,  0.05,  0.05, &
       0.05 , 0.   , 0.1  ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.8 ,  0.5 , &
       0.5      / 

      DATA   MW          /                &
       64.  , 98.  , 46.  ,  48. ,  34. , &
       63.  , 47.  , 79.  ,  17. ,  121., &
       135. , 183. , 147. ,  30. ,  44. , &
       58.  , 72.  , 128. ,  106.,  70. , &
       70.  , 72.  , 32.  ,  46. ,  60. , &
       104. , 46.  , 60.  ,  48. ,  77. , &
       147.     /

!  Maximum snow depth over which snow fraction for leaves is 1.0
!  Snow fraction for ground is treated 2 times of that for leaves 

      DATA SDMAX  /                                        &
                   9999. , 1.0   , 9999. ,  200. ,  400. , &
                    200. , 200.  ,  400. ,  200. ,   50. , &
                     50. ,  50.  ,   5.  ,   20. ,   10. , &
                     10. ,  10.  ,  10.  ,   10. ,   10. , &
                     50. ,   2.  ,  10.  ,    2. ,  200. , &
                    200.        / 


!   Parameters for collection efficiency 
!   PLLP1 and PLLP2 are minimum and maximum leaf dimension for each LUC. 

      DATA   AEST       /                 &
       100. , 50.  , 100. ,  1.0 ,  0.8 , &  
        1.1 , 0.8  ,  0.6 ,  1.0 ,  1.1 , &
        1.1 , 1.2  ,  1.2 ,  1.2 ,  1.2 , &
        1.2 , 1.2  ,  1.1 ,  1.2 ,  1.2 , &
        1.5 , 50.  ,  2.0 ,  50. ,  0.8 , &
        0.8         /
      DATA   GAMA       /                 &
        0.5 , 0.54 ,  0.5 , 0.56 , 0.56 , &
       0.56 , 0.56 , 0.58 , 0.56 , 0.55 , &
       0.55 , 0.54 , 0.54 , 0.55 , 0.54 , &
       0.54 , 0.54 , 0.55 , 0.54 , 0.54 , &
       0.56 , 0.54 , 0.54 , 0.54 , 0.56 , &
       0.56        / 
      DATA   PLLP1         /              &
       -0.9 , -0.9 , -0.9 ,  2.0 ,  5.0 , &
        2.0 ,  5.0 ,  5.0 ,  5.0 ,  5.0 , &
        5.0 ,  2.0 ,  2.0 ,  2.0 ,  2.0 , &
        2.0 ,  5.0 ,  5.0 ,  5.0 ,  2.0 , &
       10.0 , -0.9 , 10.0 , -0.9 ,  5.0 , &
        5.0        /
      DATA   PLLP2         /              &
       -0.9 , -0.9 , -0.9 ,  2.0 ,  5.0 , &
        5.0 , 10.0 ,  5.0 , 10.0 ,  5.0 , &
       10.0 ,  5.0 ,  5.0 ,  5.0 ,  5.0 , &
        5.0 , 10.0 , 10.0 , 10.0 ,  5.0 , &
       10.0 , -0.9 , 10.0 , -0.9 ,  5.0 , &
        5.0        /

!   Parameter for particle property for fine and coarse SO4, NO3, NH4, Cl(orNa)
!   K+, Mg2+, Ca2+ 

      DATA   RHOP  / 1769., 1769., 1769., 1769.,  &
       1769., 1769., 2170., 2170., 2170., 2170.,  &
       2170., 2170., 2170., 2170.   / 
      DATA   DG   / 0.38,  4.2,  0.5,  4.5,  0.38, 4.2  , &
        0.5,  4.8,  0.30,  4.5,  1.0,  4.9,   0.7, 5.2  /    
      DATA   GSD  /  2.2, 1.45,  2.2, 1.45,  2.2,  1.45 , &
        4.0, 1.45,   3.5, 1.45,  2.5, 1.45,  4.0,  1.45 /     
!  size2 is used to set up the particle size upper boundary using a lognormal distribution  
      DATA  SIZE2 /  6.0,  5.8,  5.6,  5.8,  6.0,  5.8,   &
           3.0, 5.6, 4.0,  5.8,  3.0,  5.4,  2.5,  5.2  / 

! ---  parameters for air dynamic properties 
      DATA AA1/1.257/, AA2/0.4/, AA3/1.1/
      DATA AMFP /6.53E-8/, ROAROW/1.19/, &
          BOLTZK/1.3806044503487214E-23/   

! --- Define the function for saturation vapor pressure (mb) 

      ES(TEMP) = 6.108*EXP(17.27*(TEMP - 273.16)/(TEMP - 35.86))

!      ES = 6.108*EXP(17.27*(TEMP - 273.16)/(TEMP - 35.86))
!print*,'ES=',ES(TEMP) 
!   Some constants 

      dair=0.369*29.+6.29  
      dh2o=0.369*18.+6.29

!   Initialize Leaf Area Index for LUC with constant LAI values
      DO im=1, 15 
      LAI(1,im)=0.
      LAI(2,im)=0.
      LAI(3,im)=0.
      LAI(4,im)=5.
      LAI(5,im)=6.
      LAI(8,im)=6.
      LAI(9,im)=4.
      LAI(10,im)=3.
      LAI(12,im)=3.
      LAI(13,im)=1.
      LAI(20,im)=1.
      LAI(23,im)=4.
      LAI(24,im)=0.
      END DO

!      Call init1(VDG,NG)
!      Call init1(VDP,NP)
      VDG = 0.
      VDP = 0.

! Loop 200 for LUC  

      DO 200 I=1,LUC
      
      IF (FLAND(I).LT.0.005) GO TO 200  

! interpolate LAI

           IM = INT(iday / 30.5 ) + 1
           iday_M =iday - INT((IM-1)*30.5+0.5) 
           IF (iday_M.EQ.0) THEN
           IM=IM-1
           iday_M =iday - (IM-1)*30.5
           END IF

           LAI_F  = LAI(I,IM)            & 
               + iday_M / 30.5 * (LAI(I,IM+1)-LAI(I,IM))

!print*,'LAI_F=',LAI_F
!    Set minimum wind speed as 1.0 m/s 
           U2 = amax1(U2,0.8) 
!    Potential temperature at reference height Z2 
           T2P = T2 + Z2 * 0.0098 

! calculating friction velocity and stability related varibles

! for water surfaces (LUC 1, 3), z0 is a function of wind speed
!print*,'I=',I

      IF(I.EQ.1.OR.I.EQ.3)  THEN 
             E = RH * ES(T2)
!             E = RH * ES           
             Q = 0.622 * E/(PMB-E)
             T2PV = T2P * (1. + 0.61 * Q)
             E = ES(TS)  
!print*,'E=',E
             QS = 0.622 * E / (PMB - E) 
             TSV = TS * (1. + 0.61 * QS)
             DTHV = (T2PV - TSV)
             CUN=7.5E-4+6.7E-5*U2
             EL=9999.
             IF(ABS(DTHV).GT.1.0E-6)                &
             EL=T2PV*CUN**1.5*U2**2/(5.096E-3*DTHV)
             IF(EL.GT.0..AND.EL.LT.5.0) EL = 5.0
             IF(EL.GT.-5.0.AND.EL.LT.0) EL =-5.0
             ZL = Z2/EL
             ZL10m=10./EL

             IF(ZL.LT.0.0) THEN
                X=(1.0 - 15.0*ZL)**0.25
                PSIU=2.*ALOG(0.5*(1.0+X))+ALOG(0.5*(1.0+X*X))-   &
                       2.0*ATAN(X) + 0.5*3.1415926 
                Y=SQRT(1.-9.*ZL)
                PSIT=2.*0.74*ALOG((1+Y)/2.)
             ELSE
                PSIU = -4.7*ZL
                PSIT = PSIU
             ENDIF

             Z0_F = 0.000002 * U2**2.5
             USTAR = 0.4*U2/(ALOG(Z2/Z0_F) - PSIU)
            THSTAR = 0.4*(T2P-TS)/(0.74*ALOG(Z2/Z0_F)-PSIT)

!  for LUC other than water 

      ELSE

             IF (Z02(I).GT.Z01(I)) THEN
              Z0_F=Z01(I)+(LAI_F-LAI(I,14))/(LAI(I,15)-LAI(I,14))   &
                           *(Z02(I)-Z01(I)) 
             ELSE
              Z0_F=Z01(I) 
             END IF
!print*,'Z0_F=',Z0_F
!print*,'Z2=',Z2
             RIB = 9.81*Z2*(T2P - TS)/(TS*U2**2)
!print*,'RIB=',RIB
             IF (SRAD.GT.0.0.AND.RIB.GT.0.0) RIB = 1.E-15
             DELTAT = T2P - TS
!print*,'dt=',DELTAT
             IF(ABS(DELTAT).LT.1.E-10) DELTAT=SIGN(1.E-10,DELTAT)
             TBAR = 0.5*(T2P + TS)
             RATIOZ = Z2/Z0_F
!print*,RATIOZ
             ASQ = 0.16/(ALOG(RATIOZ))**2
!print*,'ASQ=',ASQ
             IF(RIB.LE.0.)THEN
               AA = ASQ*9.4*SQRT(RATIOZ)
               CM = 7.4*AA
               CH = 5.3*AA
               FM = 1. - (9.4*RIB/(1. + CM*SQRT(ABS(RIB))))
               FH = 1. - (9.4*RIB/(1. + CH*SQRT(ABS(RIB))))
             ELSE
               FM = 1./((1. + 4.7*RIB)**2)
               FH = FM
             ENDIF
!print*,'FH=',FH
              USTARSQ = ASQ*U2**2*FM
              UTSTAR = ASQ*U2*DELTAT*FH/0.74
              USTAR = SQRT(USTARSQ)
              THSTAR = UTSTAR/USTAR
              EL = TBAR*USTARSQ/(0.4*9.81*THSTAR)
             IF(EL.GT.0..AND.EL.LT.5.0) EL = 5.0
             IF(EL.GT.-5.0.AND.EL.LT.0) EL =-5.0
              ZL=Z2/EL
              ZL10m=10./EL
      ENDIF

!print*,'zl10m=',ZL10m
!     Aerodynamic resistance above canopy

      IF(ZL.GE.0.) THEN
          Ra=(.74*ALOG(Z2/Z0_F)+4.7*ZL)/0.4/USTAR 
      ELSE
          Ra=0.74/0.4/USTAR*(ALOG(Z2/Z0_F)-     &
               2*ALOG((1+SQRT(1-9.*ZL))*0.5))
      ENDIF
      Ra=amax1(RA,5.0)
      if (I.EQ.1.OR.I.EQ.3) THEN
          Ra=amin1(RA,2000.)
      else
          Ra=amin1(RA,1000.)
      end if 
!print*,'RA above canopy=',Ra


! --- STOMATAL RESISTANCE FOR WATER VAPOR ONLY. STEPS FOR CALCULATING:
!     1. Calculate direct and diffuse PAR from solar radiation
!     2. Calculate sunlit and shaded leaf area, PAR for sunlit and shaded leafs 
!     3. Calculate stomatal conductance 
!     4. Calculate stomatal resistance for water vapor

! --- Set a big value for stomatal resistance when stomata are closed
      RST=99999.9        

! --  Only calculate stomatal resistance if there is solar radiation, 
!     leaf area index is not zero, and within reasonable temperature range

      IF (FLAND(I).GE.0.005         .AND.   &
           SRAD.GE.0.1             .AND.    &
           TS.LT.(Tmax(I)+273.15)  .AND.    &
           TS.GT.(Tmin(I)+273.15)  .AND.    &
           LAI_F.GT.0.001           .AND.   &
           COSZEN.GT.0.001               ) THEN

! --  Calculate direct and diffuse PAR from solar radiation and solar zenith angle
 
      RDU=600.*EXP(-0.185/COSZEN)*COSZEN
      RDV=0.4*(600.-RDU)*COSZEN
      WW=-ALOG(COSZEN)/2.302585  
      WW=-1.195+0.4459*WW-0.0345*WW**2
      WW=1320*10**WW
      RDM=(720.*EXP(-0.06/COSZEN)-WW)*COSZEN
      RDN=0.6*(720-RDM-WW)*COSZEN
      RV=amax1(0.1,RDU+RDV) 
      RN=amax1(0.01,RDM+RDN) 
      RATIO=amin1(0.9,SRAD/(RV+RN))
      SV=RATIO*RV                            ! Total PAR 
      FV=amin1(0.99, (0.9-RATIO)/0.7)  
      FV=amax1(0.01,RDU/RV*(1.0-FV**0.6667))  !fraction of PAR in the direct beam 
      PARDIR=FV*SV                           ! PAR from direct radiation 
      PARDIF=SV-PARDIR                       ! PAR from diffuse radiation 
  
! -- Calculate sunlit and shaded leaf area, PAR for sunlit and shaded leaves 

      IF (LAI_F.GT.2.5.AND.SRAD.GT.200.) THEN
      PSHAD=PARDIF*EXP(-0.5*LAI_F**0.8)         &
       +0.07*PARDIR*(1.1-0.1*LAI_F)*EXP(-COSZEN)
      PSUN=PARDIR**0.8*.5/COSZEN+PSHAD
      ELSE
      PSHAD=PARDIF*EXP(-0.5*LAI_F**0.7)         &
       +0.07*PARDIR*(1.1-0.1*LAI_F)*EXP(-COSZEN)
      PSUN=PARDIR*.5/COSZEN+PSHAD
      END IF
      RSHAD=RSmin(I)+BRS(I)*RSMIN(I)/PSHAD 
      RSUN=RSmin(I)+BRS(I)*RSMIN(I)/PSUN
      GSHAD=1./RSHAD
      GSUN=1./RSUN
      FSUN=2*COSZEN*(1.-EXP(-0.5*LAI_F/COSZEN))  ! Sunlit leaf area 
      FSHAD=LAI_F-FSUN                    ! Shaded leaf area 

! -- Stomatal conductance before including effects of temperature, 
!                   vapor pressure defict and water stress.

      GSPAR=FSUN*GSUN+FSHAD*GSHAD     

! --  function for temperature effect
      T=TS-273.15      
      BT=(Tmax(I)-TOPT(I))/(TOPT(I)-Tmin(I))
      GT=(Tmax(I)-T)/(TMAX(I)-TOPT(I))
      GT=GT**BT
      GT=GT*(T-Tmin(I))/(TOPT(I)-TMIN(I))  
! --  function for vapor pressure deficit 
      D0= ES(TS)*(1.- RH)/10.           !kPa 
      GD=1.-BVPD(I)*D0
! --  function for water stress 
      PSI=(-0.72-0.0013*SRAD)
!      PSI_S=(-0.395-0.043*(TS-273.15))*102.
      GW=(PSI-PSI2(I))/(PSI1(I)-PSI2(I))
      IF (GW.GT.1.0) GW=1.0
      IF (GW.LT.0.1) GW=0.1
      IF (GD.GT.1.0) GD=1.0
      IF (GD.LT.0.1) GD=0.1
! --  Stomatal resistance for water vapor 
      RST=1.0/(GSPAR*GT*GD*GW)    

      END IF

!print*,'RST=',RST
!   Decide if dew or rain occurs.

      IF (FCLD.LT.0.25) THEN
        Coedew=0.3  
      ELSE  IF (FCLD.GE.0.25.AND.FCLD.LT.0.75) THEN 
         Coedew=0.2  
      ELSE
        Coedew=0.1  
      END IF
         DQ=0.622/1000. * ES(TS)*(1.- RH)*1000.    ! unit g/kg 
         DQ=amax1(0.0001,DQ)
         USMIN=1.5/DQ*Coedew  
 
      IF (TS.GT.273.15 .AND. PREC.GT.0.20) then
        is_rain = .true. 
        is_dew = .false. 
      ELSE IF (TS.GT.273.15 .AND. USTAR.LT.USMIN)THEN 
        is_dew = .true. 
        is_rain = .false. 
      ELSE
        is_rain = .false. 
        is_dew = .false. 
      END IF

!   Decide fraction of stomatal blocking due to wet conditions 
 
      Wst=0.
      if ((is_dew.or.is_rain).and.SRAD.GT.200.) then
      Wst=(SRAD-200.)/800.
      Wst=amin1(Wst, 0.5) 
      end if 

!print*,'Wst=',Wst
! -- In-canopy aerodynamic resistance 

        Rac = Rac1(I)+(LAI_F-LAI(I,14))/(LAI(I,15)-LAI(I,14)+1.E-10)  &
                 *(Rac2(I)-Rac1(I)) 
        Rac = Rac*LAI_F**0.25/USTAR/USTAR 

! -- Ground resistance for O3 

      IF (I.GE.4.AND.TS.LT.272.15) THEN 
        RgO_F = amin1( RgO(I)*2., RgO(I) * exp(0.2*(272.15-TS))) 
      ELSE
        RgO_F = RgO(I)
      END IF

! -- Ground resistance for SO2 

      IF (I.EQ.2) THEN 
        RgS_F = AMIN1(RgS(I)*(275.15-TS), 500.) 
        RgS_F = AMAX1(RgS(I), 100.) 
      ELSE IF (I.GE.4.AND.is_rain) THEN
        RgS_F = 50. 
      ELSE IF (I.GE.4.AND.is_dew) THEN
        RgS_F = 100. 
      ELSE IF (I.GE.4.AND.TS.LT.272.15) THEN
        RgS_F = amin1( RgS(I)*2., RgS(I) * exp(0.2*(272.15-TS))) 
      ELSE 
        RgS_F =  RgS(I)
      END IF

!print*,'RgS_F=',RgS_F
! -- Cuticle resistance for O3 AND SO2  

      IF (RcutdO(I).LE.-1) THEN 
        RcutO_F = 1.E25 
        RcutS_F = 1.E25 
      ELSE IF (is_rain) THEN
        RcutO_F = RcutwO(I)/LAI_F**0.5/USTAR 
        RcutS_F = 50./LAI_F**0.5/USTAR 
        RcutS_F = MAX (RcutS_F, 20.) 
      ELSE IF (is_dew) THEN
        RcutO_F = RcutwO(I)/LAI_F**0.5/USTAR 
        RcutS_F = 100./LAI_F**0.5/USTAR 
        RcutS_F = MAX (RcutS_F, 20.) 
      ELSE IF (TS.LT.272.15) THEN
        RcutO_F = RcutdO(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
        RcutS_F = RcutdS(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
        RcutO_F = amin1( RcutO_F*2., RcutO_F * exp(0.2*(272.15-TS))) 
        RcutS_F = amin1( RcutS_F*2., RcutS_F * exp(0.2*(272.15-TS))) 
        RcutO_F = MAX (RcutO_F,100.) 
        RcutS_F = MAX (RcutS_F,100.) 
      ELSE 
        RcutO_F = RcutdO(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
        RcutS_F = RcutdS(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
        RcutO_F = MAX (RcutO_F,100.) 
        RcutS_F = MAX (RcutS_F,100.) 
      END IF

! If snow occurs, Rg and Rcut are adjusted by snow cover fraction

        fsnow= sd/sdmax(i)
        fsnow= amin1(1.0, fsnow)   !snow cover fraction for leaves 
      If (fsnow.GT.0.0001.and.I.GE.4) THEN
        RsnowS= AMIN1(70.*(275.15-TS), 500.) 
        RsnowS= AMAX1(RSnowS, 100.) 
        RcutS_F=1.0/((1.-fsnow)/RcutS_F+fsnow/RsnowS) 
        RcutO_F=1.0/((1.-fsnow)/RcutO_F+fsnow/2000.) 
        fsnow= amin1(1.0, fsnow*2.)   !snow cover fraction for ground 
        RgS_F=1.0/((1.-fsnow)/RgS_F+fsnow/RsnowS) 
        RgO_F=1.0/((1.-fsnow)/RgO_F+fsnow/2000.) 
      END IF

!print*,'RgO_F=',RgO_F

! Loop 100 for gas species 

      DO 100 J=1,NG

! -- Calculate diffusivity for each gas species

        dgas=0.369*MW(J)+6.29  
        DI=0.001*TS**1.75*SQRT((29.+MW(J))/MW(J)/29.)      
        DI=DI/1.0/(dair**0.3333+dgas**0.3333)**2    
        VI=145.8*1.E-4*(TS*0.5+T2*0.5)**1.5/      &
                       (TS*0.5+T2*0.5+110.4)
        VI=VI/ROAROW 

!print*,'VI=',VI
! -- Calculate quasi-laminar resistance 

        Rb(J)  =5./USTAR_INPT*(VI/DI)**.666667   
!print*,'Rb=',Rb(J)
! -- Calculate stomatal resistance for each species from the ratio of
!       diffusity of water vapor to the gas species

        DVh2o=0.001*TS**1.75*SQRT((29.+18.)/29./18.)
        DVh2o=DVh2o/(dair**0.3333+dh2o**0.3333)**2
        RS=RST*DVh2o/DI+RM(J) 
        Dratio(J)=DVh2o/DI
! -- Scale cuticle and ground resistances for each species 

        Rcut(J) = 1./(ALPHA(J)/RcutS_F+BETA(J)/RcutO_F)
        Rg(J) = 1./(ALPHA(J)/RgS_F+BETA(J)/RgO_F)

! -- Calculate total surface resistance  

        Rc(J) = (1.-Wst)/Rs+1./(Rac+Rg(J))+1./Rcut(J)
        Rc(J)=amax1(10.0,1./Rc(J))        !Set minimum surface resistance as 10 s/m 
        Rns(J)=1./(1./(Rac+Rg(J))+1./Rcut(J))
        RM2(J)=RM(J)
! -- Deposition velocity 

        VDF = 1./(RA+RB(J)+RC(J))    
        VDG(J) = VDG(J) + VDF*FLAND(I)*100. ! convert to cm/s from m/s    

!print*,'VDF=',VDF
 28   FORMAT (A18, I6, I3, I4, F6.2, F8.3)
100   CONTINUE   ! end of gaseous species 


! Loop 150 for particle species 

        PLLP = PLLP2(I)-(LAI_F-LAI(I,14))/(LAI(I,15)-LAI(I,14)+1.E-10)    &
                *(PLLP2(I)-PLLP1(I)) 

      DO 150 J=1,NP

      EINC = SIZE2(J)/FLOAT(NSIZE)
      SGL =ALOG(GSD(J))
      RT2 = SQRT (2.0)
      DB(1) = DG(J)*GSD(J)**(-SIZE2(J)*0.5)

      DO IB = 1,NSIZE
      DB(IB+1) = DG(J)*GSD(J)**(-SIZE2(J)*0.5+IB*EINC)
      BINSIZE(IB) = EXP(ALOG(DB(IB)*DB(IB+1))*0.5)*0.5E-6    ! radius 
      FSIZE(IB) = 0.5*(ERF(ALOG(DB(IB+1)/DG(J))/(SGL*RT2))-    &
          ERF(ALOG(DB(IB)/DG(J))/(SGL*RT2)))
      END DO

!print*,'Fsize=',FSIZE(IB)

      TAVE=0.5*(T2+TS)
!print*,'TAVE=',TAVE

      VDPF=0.
      DO 50 KK=1,NSIZE 
!     * AIR'S DYNAMIC VISCOSITY
              AMU=145.8*1.E-8*TAVE**1.5/(TAVE+110.4)
!     * AIR'S KINEMATIS VISCOSITY
              ANU=AMU/ROAROW
!     * CUNNINGHAM SLIP CORRECTION FACTOR AND RELAXATION TIME = vg/Grav.
              PRII=2./9.*9.81/AMU
              PRIIV=PRII*(RHOP(J)-ROAROW)
              VPHIL=0.
              CFAC=1.+AMFP/BINSIZE(KK)*(AA1+AA2*                 &
                                     EXP(-AA3*BINSIZE(KK)/AMFP))
              TAUREL=AMAX1(PRIIV*BINSIZE(KK)**2*CFAC/9.81,0.0)
!
!     * STOKES FRICTION AND DIFFUSION COEFFICIENTS.

              AMOB=6.*3.14*AMU*BINSIZE(KK)/CFAC
              DIFF=BOLTZK*TAVE/AMOB
              SCHM=ANU/DIFF
!     * GRAVITATIONAL SETTLING VELOCITY.
             PDEPV =TAUREL*9.81

!     * Efficiency by diffusion, impaction, interception and particle rebound.
             IF (PLLP.LE.0.) then
                St=TAUREL*USTAR*USTAR/ANU
             else
                St=TAUREL*USTAR/PLLP*1000.
            end if
             EB= SCHM**(-gama(I)) 
             EIM=( St/(St+AEST(I)))**2
             EIN=0.0
             IF (PLLP .GT. 0.00) THEN
             EIN=(1000.*2.*BINSIZE(KK)/PLLP)**2*0.5 
             END IF
             R1= EXP(-ST**0.5)
             IF (R1.LT.0.5) R1=0.5
           RS= 1./3./USTAR/(EB+EIM+EIN)/R1

!print*,'RS=',RS
! -- Deposition velocity 

          VDSIZE = PDEPV + 1./(RA+RS) 

        VDPF=VDPF+VDSIZE*FSIZE(KK)  

50    CONTINUE                                                           

      VDP(J) = VDP(J) + VDPF*FLAND(I)*100. ! convert to cm/s from m/s    

52    format (A20,2I3,8E10.2) 

150   CONTINUE   ! end of particle species 

200   CONTINUE   ! end of LUC 
!      write(6,*) 'VDG=', VDG 
!      write(6,*) 'VDP=', VDP 

      RETURN
  END SUBROUTINE DRYVD

  SUBROUTINE nonstomatal_zhang (sd, LAI_F, t2, ts, rh, fcld, prec, fland, USTAR,is_rain,is_dew,  &
                                Rb, Rac, Rg, Rcut, Rns, Dratio, RM2) 
!
!    PURPOSE ---- Calculate the non-stomatal resistance (Rns)for 31 gas species 
!
!    References: 
!      for gas: Zhang et al., 2003.  Atmos. Chem. Phys. 3, 2067-2082 
!
!                        leiming.zhang@ec.gc.ca    1 (416) 739-5734
!-----------------------------------------------------------------------
!
!     LUC No.     Vegetation type
!     =====       ===============
!       1         water
!       2         ice
!       3         inland lake
!       4         evergreen needleleaf trees
!       5         evergreen broadleaf trees
!       6         deciduous needleleaf trees
!       7         deciduous broadleaf trees
!       8         tropical broadleaf trees
!       9         drought deciduous trees
!       10        evergreen broadleaf shrub
!       11        deciduous shrubs
!       12        thorn shrubs
!       13        short grass and forbs
!       14        long grass
!       15        crops
!       16        rice
!       17        sugar
!       18        maize
!       19        cotton
!       20        irrigated crops
!       21        urban
!       22        tundra
!       23        swamp
!       24        desert
!       25        mixed wood forests
!       26        transitional forest 
!-----------------------------------------------------------------------
!        KEY   VARIABLES
!-----------------------------------------------------------------------
!  alpha    | Scaling factor based on SO2 (no unit) 
!  beta     | Scaling factor based on O3  (no unit) 
!  bvpd     | Constant for water vapor pressure deficit  (kPa^-1)                   
!  fcld     | Cloud fraction (0.0-1.0)              
!  fland    | fraction of Land types (%)            
!  lai      | Leaf area index  (no unit)           
!  luc      | No. of land use category (26)        
!  mw       | molecular weight for gaseous species  
!           |   (g/mol)                             
!  ng       | No. of gaseous species dry deposited  
!  prec     | hourly precipitation amount (mm/hour) 
!  fsnow    | Snow fraction  (0.0-1.0)              
!  rac      | IN-canopy aerodynamic resistance (s/m)         
!  rb       | quasi-laminar resistance (s/m)      
!  rcut     | cuticle resistance (s/m )              
!  rcutdo   | Dry cuticle resistance for O3 (s/m)  
!  rcutds   | Dry cuticle resistance for SO2 (s/m)
!  rcutwo   | Wet cuticle resistance for O3 (s/m)  
!  rg       | Ground  resistance (s/m )                
!  rgo      | Ground  resistance for O3 (s/m)  
!  rgs      | Ground  resistance for SO2 (s/m) 
!  rh       | relative humidity (0.0-1.0)                
!  rm       | mesophyll resistance (s/m)           
!  sd       | Snow depth        (cm)             
!  sdmax    | Maximum snow depth over which snow  
!           |   fraction for leaves is 1 (cm )              
!  t2       | Temperature  at first level (K)      
!  ts       | Surface temperature (K)             
!  ustar    | friction velocity (m/s)               
!  VDF      | dry deposition velocity for one LUC   
!  VDG      | gaseous dry deposition velocity (m/s) 
!  wst      | fraction of stomatal closure under   
!           |      wet conditions (0.0-0.5)          
!  z0       | roughness length (m)                

      IMPLICIT REAL(A-H,O-Z),INTEGER(I-N)        
      INTEGER :: ng, luc 
      PARAMETER (ng=31)        ! NUMBER OF GAS SPECIES DRY DEPOSITED
      PARAMETER (luc=26)       ! NUMBER OF LAND-USE CATEGORIES

!  paramaters 

      REAL FLAND(LUC)
      REAL LAI(LUC,15),LAI_F

!  paramaters for gaseous Vd submoudle 
      REAL VDG(NG), ALPHA(NG),BETA(NG),MW(NG), RM(NG), RM2(NG)
      REAL, DIMENSION(NG) :: Rb, Rg, Rcut, Rc, Rns, Dratio 
      REAL Rac1(LUC),   Rac2(LUC), RcutdO(LUC), RcutwO(LUC),  &
         RcutdS(LUC),   RgS(LUC),  RgO(LUC),  SDmax(LUC)     
      LOGICAL is_dew, is_rain

      real :: dair, dh2o
      real :: Coedew, DQ, USMIN
      integer :: I
!   In-canopy aerodynamic resistance  [s/m].
!   Rac1 and Rac2 are minimum and maximum Rac0 for each LUC. 

      DATA   Rac1            /            &
        0   ,  0   ,  0   ,  100 ,  250 , &
        60  ,  100 ,  300 ,  100 ,  60  , &
        20  ,  40  ,  20  ,  10  ,  10  , &
        10  ,  10  ,  10  ,  10  ,  20  , &
        40  ,  0   ,  20  ,  0   ,  100 , &
        100    /
      DATA   Rac2            /            &
        0   ,  0   ,  0   ,  100 ,  250 , &
        100 ,  250 ,  300 ,  100 ,  60  , &
        60  ,  40  ,  20  ,  40  ,  40  , &
        40  ,  40  ,  50  ,  40  ,  20  , &
        40  ,  0   ,  20  ,  0   ,  100 , &
        100    /

!   Dry and wet cuticle resistance for O3  [s/m].

      DATA   RcutdO          /            &
       -999 , -999 , -999 , 4000 , 6000 , &
       4000 , 6000 , 6000 , 8000 , 6000 , &
       5000 , 5000 , 4000 , 4000 , 4000 , &
       4000 , 4000 , 5000 , 5000 , 4000 , &
       6000 , 8000 , 5000 , -999 , 4000 , &
       4000    /
      DATA   RcutwO          /            &
       -999 , -999 , -999 ,  200 ,  400 , &
        200 ,  400 ,  400 ,  400 ,  400 , &
        300 ,  300 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  300 ,  300 ,  200 , &
        400 ,  400 ,  300 , -999 ,  200 , &
        200    /

!   Ground resistance for O3  [s/m].

      DATA   RgO            /             &
       2000 , 2000 , 2000 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  500 , &
        500 ,  500 ,  500 ,  500 ,  200 , &
        200    /

!   Dry cuticle resistance for SO2  [s/m].

      DATA   RcutdS          /            &
       -999 , -999 , -999 , 2000 , 2500 , &
       2000 , 2500 , 2500 , 6000 , 2000 , &
       2000 , 2000 , 1000 , 1000 , 1500 , &
       1500 , 2000 , 2000 , 2000 , 2000 , &
       4000 , 2000 , 1500 , -999 , 2500 , &
       2500    /

!   Ground resistance for SO2  [s/m].

      DATA   RgS            /             &
         20 ,   70 ,  20  ,  200 ,  100 , &
        200 ,  200 ,  100 ,  300 ,  200 , &
        200 ,  200 ,  200 ,  200 ,  200 , &
         50 ,  200 ,  200 ,  200 ,   50 , &
        300 ,  300 ,   50 ,  700 ,  200 , &
        200    /

! Leaf area index at the beginning of each month (im=1,13), 
!  minimum LAI (im=14) and maximum LAI (im=15).
! Values of LAI are from GEM, provided by Stephane Belair and Judy St-James,
! with modifications for urban.

      DATA (LAI(6,im), im = 1, 15)/       &
       0.1  , 0.1  , 0.5  , 1.0  , 2.0  , &
       4.0  , 5.0  , 5.0  , 4.0  , 2.0  , &
       1.0  , 0.1  , 0.1  , 0.1  , 5.0  /
      DATA (LAI(7,im), im = 1, 15)/       &
       0.1  , 0.1  , 0.5  , 1.0  , 2.0  , &
       4.0  , 5.0  , 5.0  , 4.0  , 2.0  , &
       1.0  , 0.1  , 0.1  , 0.1  , 5.0  / 
      DATA (LAI(11,im), im = 1, 15)/      &
       0.5  , 0.5  , 1.0  , 1.0  , 1.5  , &
       2.0  , 3.0  , 3.0  , 2.0  , 1.5  , &
       1.0  , 0.5  , 0.5  , 0.5  , 3.0  /
      DATA (LAI(14,im), im = 1, 15)/      &
       0.5  , 0.5  , 0.5  , 0.5  , 0.5  , &
       0.5  , 1.0  , 2.0  , 2.0  , 1.5  , &
       1.0  , 1.0  , 0.5  , 0.5  , 2.0  /
      DATA (LAI(15,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.0  , 3.0  , 3.5  , 4.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 4.0  /
      DATA (LAI(16,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.5  , 4.0  , 5.0  , 6.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 6.0  /
      DATA (LAI(17,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       3.0  , 4.0  , 4.5  , 5.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 5.0  /
      DATA (LAI(18,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       2.0  , 3.0  , 3.5  , 4.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 4.0  /
      DATA (LAI(19,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.5  , 1.0  , &
       3.0  , 4.0  , 4.5  , 5.0  , 0.1  , &
       0.1  , 0.1  , 0.1  , 0.1  , 5.0  /  
      DATA (LAI(21,im), im = 1, 15)/      &
       0.1  , 0.1  , 0.1  , 0.1  , 0.5  , &
       1.0  , 1.0  , 1.0  , 1.0  , 1.0  , &
       0.4  , 0.1  , 0.1  , 0.1  , 1.0  /
      DATA (LAI(22,im), im = 1, 15)/      &
       1.0  , 1.0  , 0.5  , 0.1  , 0.1  , &
       0.1  , 0.1  , 1.0  , 2.0  , 1.5  , &
       1.5  , 1.0  , 1.0  , 0.1  , 2.0  /
      DATA (LAI(25,im), im = 1, 15)/      &
       3.0  , 3.0  , 3.0  , 4.0  , 4.5  , &
       5.0  , 5.0  , 5.0  , 4.0  , 3.0  , &
       3.0  , 3.0  , 3.0  , 3.0  , 5.0  /
      DATA (LAI(26,im), im = 1, 15)/      &
       3.0  , 3.0  , 3.0  , 4.0  , 4.5  , &
       5.0  , 5.0  , 5.0  , 4.0  , 3.0  , &
       3.0  , 3.0  , 3.0  , 3.0  , 5.0  /

!  Gas Properties (Total 31 species)
  
!  Mesophyll resistance RM, scaling factors ALPHA and BETA, molecular weight.

      DATA   RM            /              &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  100., &
       100. , 100. , 100. ,  100.,  0.  , &
       100. , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  100., &
       100.     / 

      DATA   ALPHA          /             &
       1.   , 1.   , 0.   ,  0.  ,  1.  , &
       10.  , 2.   , 5.   ,  1.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.8 ,  0.  , &
       0.   , 0.   , 0.   ,  0.  ,  0.  , &
       0.   , 0.01 , 0.6  ,  0.6 ,  0.4 , &
       0.01 , 2.   , 1.5  ,  0.1 ,  0.  , &
       0.       / 

      DATA   BETA          /              &
       0.   , 1.   , 0.8  ,  1.  ,  1.  , &
       10.  , 2.   , 5.   ,  0.0 ,  0.6 , &
       0.6  , 0.8  , 0.3  ,  0.2 ,  0.05, &
       0.05 , 0.05 , 0.05 ,  0.05,  0.05, &
       0.05 , 0.   , 0.1  ,  0.  ,  0.  , &
       0.   , 0.   , 0.   ,  0.8 ,  0.5 , &
       0.5      / 

      DATA   MW          /                &
       64.  , 98.  , 46.  ,  48. ,  34. , &
       63.  , 47.  , 79.  ,  17. ,  121., &
       135. , 183. , 147. ,  30. ,  44. , &
       58.  , 72.  , 128. ,  106.,  70. , &
       70.  , 72.  , 32.  ,  46. ,  60. , &
       104. , 46.  , 60.  ,  48. ,  77. , &
       147.     /

!  Maximum snow depth over which snow fraction for leaves is 1.0
!  Snow fraction for ground is treated 2 times of that for leaves 

      DATA SDMAX  /                                        &
                   9999. , 1.0   , 9999. ,  200. ,  400. , &
                    200. , 200.  ,  400. ,  200. ,   50. , &
                     50. ,  50.  ,   5.  ,   20. ,   10. , &
                     10. ,  10.  ,  10.  ,   10. ,   10. , &
                     50. ,   2.  ,  10.  ,    2. ,  200. , &
                    200.        / 

! ---  parameters for air dynamic properties 
      DATA ROAROW/1.19/

! --- Define the function for saturation vapor pressure (mb) 
      ES(TEMP) = 6.108*EXP(17.27*(TEMP - 273.16)/(TEMP - 35.86))
 
!   Some constants 
      dair=0.369*29.+6.29  
      dh2o=0.369*18.+6.29

!   Initialize Leaf Area Index for LUC with constant LAI values
      DO im=1, 15 
      LAI(1,im)=0.
      LAI(2,im)=0.
      LAI(3,im)=0.
      LAI(4,im)=5.6
      LAI(5,im)=6.
      LAI(8,im)=6.
      LAI(9,im)=4.
      LAI(10,im)=3.
      LAI(12,im)=3.
      LAI(13,im)=1.
      LAI(20,im)=1.
      LAI(23,im)=4.
      LAI(24,im)=0.
      END DO

      VDG = 0.

! Loop 200 for LUC  

      DO 200 I=1,LUC
      
        IF (FLAND(I).LT.0.005) GO TO 200  

!   Decide if dew or rain occurs.

!        IF (FCLD.LT.0.25) THEN
!          Coedew=0.3  
!        ELSE  IF (FCLD.GE.0.25.AND.FCLD.LT.0.75) THEN 
!          Coedew=0.2  
!        ELSE
!          Coedew=0.1  
!        END IF
!        DQ=0.622/1000. * ES(TS)*(1.- RH)*1000.    ! unit g/kg 
!        DQ=amax1(0.0001,DQ)
!        USMIN=1.5/DQ*Coedew  
 
!        IF (TS.GT.273.15 .AND. PREC.GT.0.20) then
!          is_rain = .true. 
!          is_dew = .false. 
!        ELSE IF (TS.GT.273.15 .AND. USTAR.LT.USMIN)THEN 
!          is_dew = .true. 
!          is_rain = .false. 
!        ELSE
!          is_rain = .false. 
!          is_dew = .false. 
!        END IF

! -- In-canopy aerodynamic resistance 

        Rac = Rac1(I)+(LAI_F-LAI(I,14))/(LAI(I,15)-LAI(I,14)+1.E-10)  &
                 *(Rac2(I)-Rac1(I)) 
        Rac = Rac*LAI_F**0.25/USTAR/USTAR 

! -- Ground resistance for O3 

        IF (I.GE.4.AND.TS.LT.272.15) THEN 
          RgO_F = amin1( RgO(I)*2., RgO(I) * exp(0.2*(272.15-TS))) 
        ELSE
          RgO_F = RgO(I)
        END IF

! -- Ground resistance for SO2 

        IF (I.EQ.2) THEN 
          RgS_F = AMIN1(RgS(I)*(275.15-TS), 500.) 
          RgS_F = AMAX1(RgS(I), 100.) 
        ELSE IF (I.GE.4.AND.is_rain) THEN
          RgS_F = 50. 
        ELSE IF (I.GE.4.AND.is_dew) THEN
          RgS_F = 100. 
        ELSE IF (I.GE.4.AND.TS.LT.272.15) THEN
          RgS_F = amin1( RgS(I)*2., RgS(I) * exp(0.2*(272.15-TS))) 
        ELSE 
          RgS_F =  RgS(I)
        END IF

! -- Cuticle resistance for O3 AND SO2  

        IF (RcutdO(I).LE.-1) THEN 
          RcutO_F = 1.E25 
          RcutS_F = 1.E25 
        ELSE IF (is_rain) THEN
          RcutO_F = RcutwO(I)/LAI_F**0.5/USTAR 
          RcutS_F = 50./LAI_F**0.5/USTAR 
          RcutS_F = MAX (RcutS_F, 20.) 
        ELSE IF (is_dew) THEN
          RcutO_F = RcutwO(I)/LAI_F**0.5/USTAR 
          RcutS_F = 100./LAI_F**0.5/USTAR 
          RcutS_F = MAX (RcutS_F, 20.) 
        ELSE IF (TS.LT.272.15) THEN
          RcutO_F = RcutdO(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
          RcutS_F = RcutdS(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
          RcutO_F = amin1( RcutO_F*2., RcutO_F * exp(0.2*(272.15-TS))) 
          RcutS_F = amin1( RcutS_F*2., RcutS_F * exp(0.2*(272.15-TS))) 
          RcutO_F = MAX (RcutO_F,100.) 
          RcutS_F = MAX (RcutS_F,100.) 
        ELSE 
          RcutO_F = RcutdO(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
          RcutS_F = RcutdS(I)/exp(3.*RH)/LAI_F**0.25/USTAR 
          RcutO_F = MAX (RcutO_F,100.) 
          RcutS_F = MAX (RcutS_F,100.) 
        END IF

! If snow occurs, Rg and Rcut are adjusted by snow cover fraction

        fsnow= sd/sdmax(i)
        fsnow= amin1(1.0, fsnow)   !snow cover fraction for leaves 
        If (fsnow.GT.0.0001.and.I.GE.4) THEN
          RsnowS= AMIN1(70.*(275.15-TS), 500.) 
          RsnowS= AMAX1(RSnowS, 100.) 
          RcutS_F=1.0/((1.-fsnow)/RcutS_F+fsnow/RsnowS) 
          RcutO_F=1.0/((1.-fsnow)/RcutO_F+fsnow/2000.) 
          fsnow= amin1(1.0, fsnow*2.)   !snow cover fraction for ground 
          RgS_F=1.0/((1.-fsnow)/RgS_F+fsnow/RsnowS) 
          RgO_F=1.0/((1.-fsnow)/RgO_F+fsnow/2000.) 
        END IF


! Loop 100 for gas species 

        DO 100 J=1,NG

! -- Calculate diffusivity for each gas species

          dgas=0.369*MW(J)+6.29  
          DI=0.001*TS**1.75*SQRT((29.+MW(J))/MW(J)/29.)      
          DI=DI/1.0/(dair**0.3333+dgas**0.3333)**2    
          VI=145.8*1.E-4*(TS*0.5+T2*0.5)**1.5/      &
                       (TS*0.5+T2*0.5+110.4)
          VI=VI/ROAROW 

! -- Calculate quasi-laminar resistance 

          Rb(J)  =5./USTAR*(VI/DI)**.666667   

! -- Calculate the ratio of diffusity of water vapor to the gas species

          DVh2o=0.001*TS**1.75*SQRT((29.+18.)/29./18.)
          DVh2o=DVh2o/(dair**0.3333+dh2o**0.3333)**2
          Dratio(J)=DVh2o/DI

! -- Scale cuticle and ground resistances for each species 

          Rcut(J) = 1./(ALPHA(J)/RcutS_F+BETA(J)/RcutO_F)
          Rg(J) = 1./(ALPHA(J)/RgS_F+BETA(J)/RgO_F)
     
          RM2(J)=RM(J)

! -- Calculate total surface resistance  

          Rns(J)=1./(1./(Rac+Rg(J))+1./Rcut(J))

100   CONTINUE   ! end of gaseous species 

200   CONTINUE   ! end of LUC 

      RETURN
  END SUBROUTINE nonstomatal_zhang

END MODULE module_dry_dep_zhang
